@@ -113,11 +113,11 @@ class CdkCloudWatchAlarmChatBot(
 
     @builtins.property
     @jsii.member(jsii_name="topic")
-    def topic(self) -> aws_cdk.aws_sns.Topic:
+    def topic(self) -> aws_cdk.aws_sns.ITopic:
         '''
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_sns.Topic, jsii.get(self, "topic"))
+        return typing.cast(aws_cdk.aws_sns.ITopic, jsii.get(self, "topic"))
 
 
 @jsii.data_type(
